@@ -86,7 +86,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55600
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55500
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55600
 #  endif
 #endif
 
@@ -247,6 +247,12 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_84(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_86(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
@@ -313,7 +319,7 @@
 #define KIOWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOWIDGETS_NO_DEPRECATED
-#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
+#  define KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55600
 #endif
 #ifdef KIOWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -323,7 +329,7 @@
 #  ifdef KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE KIOWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55500
+#    define KIOWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55600
 #  endif
 #endif
 
@@ -474,6 +480,12 @@
 #else
 #  define KIOWIDGETS_DEPRECATED_VERSION_5_84(text)
 #endif
+
+#if KIOWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_86(text) KIOWIDGETS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOWIDGETS_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KIOWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_4_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOWIDGETS_DEPRECATED_VERSION_5_##minor(text)
 #define KIOWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
